import asyncio
from ai_hub_agents.core import setup_log
from ai_hub_agents.config import Config
from ai_hub_agents.core.agent import Agent

async def main():
    """主函数"""
    config = Config()
    setup_log(config.log_dir, config.log_level)
    agent = Agent(config=config,thread_id="example-chat")
    response = await agent.run(query="给我讲一个冷笑话",name="user")
    print(response)

if __name__ == "__main__":
    asyncio.run(main())