from ai_hub_agents.core import Callback

class A(Callback):
    name: str

class Other:
    def __init__(self):
        @A
        def _(cb:A):
            print(f"on_a: {cb.name}")


if __name__ == "__main__":
    Other()
    A(name="test")